library(testthat)
library(fanovaGraph)

test_check("fanovaGraph")